messlidger
==========

A
`feature-rich <https://slidge.im/messlidger/features.html>`_
`Facebook Messenger <https://messenger.com>`_ to
`XMPP <https://xmpp.org/>`_ puppeteering
`gateway <https://xmpp.org/extensions/xep-0100.html>`_, based on
`slidge <https://slidge.im>`_ and
`mautrix-facebook <https://github.com/mautrix/facebook>`_.

.. toctree::
   :maxdepth: 3

   readme
   features
   config
   user
   autoapi/index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
